@@ -2,9 +2,8 @@ import django_filters
 from django.db.models import Q
 
 from netbox.filtersets import NetBoxModelFilterSet
-
 from netbox_storage.models import Drive
-from virtualization.models import Cluster, VirtualMachine
+from virtualization.models import Cluster
 
 
 class DriveFilter(NetBoxModelFilterSet):
