@@ -1,3 +1,4 @@
+from django.contrib.contenttypes.models import ContentType
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
@@ -191,9 +192,14 @@ class DriveTemplateForm(NetBoxModelForm):
         template_configuration = super().save(*args, **kwargs)
 
         print(f"{self.cleaned_data['size']}")
+        drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
 
-        print("Instances")
+        linux_device = LinuxDevice.objects.create(device='/dev/sda',
+                                                  type='disk',
+                                                  object_id=drive.pk,
+                                                  content_type_id=drive_type_pk)
         print(drive)
+        print(linux_device)
         print(template_configuration)
 
         return template_configuration
