@@ -1,3 +1,4 @@
+from django.contrib.contenttypes.models import ContentType
 from django.db import migrations, models
 import utilities.json
 
@@ -96,9 +97,9 @@ class Migration(migrations.Migration):
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("device", models.CharField(max_length=255)),
                 ("type", models.CharField(max_length=255)),
-                ('mounted_volume', models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="mounted_volume_device",
-                                   to="netbox_storage.mountedvolume")),
-                ("description", models.CharField(max_length=255)),
+                ('object_id', models.PositiveIntegerField()),
+                ('content_type',
+                 models.ForeignKey(on_delete=models.deletion.CASCADE, to='contenttypes.contenttype')),
             ],
         ),
         migrations.CreateModel(
