@@ -1,7 +1,8 @@
 from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
-from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice, LogicalVolume, VolumeGroup, \
+    PhysicalVolume
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -41,8 +42,14 @@ from netbox_storage.views import (
 )
 from netbox_storage.views.linux_device import LinuxDeviceListView, LinuxDeviceEditView, LinuxDeviceBulkImportView, \
     LinuxDeviceBulkEditView, LinuxDeviceBulkDeleteView, LinuxDeviceView, LinuxDeviceDeleteView
-from netbox_storage.views.template import LVMAddTemplateView, AddTemplateVolumeView, AddTemplateDriveView, \
+from netbox_storage.views.logical_volume import LogicalVolumeDeleteView, LogicalVolumeEditView, LogicalVolumeView, \
+    LogicalVolumeListView
+from netbox_storage.views.physical_volume import PhysicalVolumeDeleteView, PhysicalVolumeEditView, PhysicalVolumeView, \
+    PhysicalVolumeListView
+from netbox_storage.views.template import LVMAddTemplateView, AddTemplateDriveView, \
     AddTemplatePartitionView
+from netbox_storage.views.volume_group import VolumeGroupDeleteView, VolumeGroupEditView, VolumeGroupView, \
+    VolumeGroupListView
 
 app_name = "netbox_storage"
 
@@ -134,6 +141,57 @@ urlpatterns = [
         kwargs={"model": LinuxDevice},
     ),
     #
+    # Logical Volume urls
+    #
+    path("logicalvolume/", LogicalVolumeListView.as_view(), name="logicalvolume_list"),
+    path("logicalvolume/add/", LogicalVolumeEditView.as_view(), name="logicalvolume_add"),
+    # path("logicalvolume/import/", LogicalVolumeBulkImportView.as_view(), name="logicalvolume_import"),
+    # path("logicalvolume/edit/", LogicalVolumeBulkEditView.as_view(), name="logicalvolume_bulk_edit"),
+    # path("logicalvolume/delete/", LogicalVolumeBulkDeleteView.as_view(), name="logicalvolume_bulk_delete"),
+    path("logicalvolume/<int:pk>/", LogicalVolumeView.as_view(), name="logicalvolume"),
+    path("logicalvolume/<int:pk>/edit/", LogicalVolumeEditView.as_view(), name="logicalvolume_edit"),
+    path("logicalvolume/<int:pk>/delete/", LogicalVolumeDeleteView.as_view(), name="logicalvolume_delete"),
+    path(
+        "logicalvolume/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="logicalvolume_changelog",
+        kwargs={"model": LogicalVolume},
+    ),
+    #
+    # Volume Group urls
+    #
+    path("volumegroup/", VolumeGroupListView.as_view(), name="volumegroup_list"),
+    path("volumegroup/add/", VolumeGroupEditView.as_view(), name="volumegroup_add"),
+    # path("volumegroup/import/", VolumeGroupBulkImportView.as_view(), name="volumegroup_import"),
+    # path("volumegroup/edit/", VolumeGroupBulkEditView.as_view(), name="volumegroup_bulk_edit"),
+    # path("volumegroup/delete/", VolumeGroupBulkDeleteView.as_view(), name="volumegroup_bulk_delete"),
+    path("volumegroup/<int:pk>/", VolumeGroupView.as_view(), name="volumegroup"),
+    path("volumegroup/<int:pk>/edit/", VolumeGroupEditView.as_view(), name="volumegroup_edit"),
+    path("volumegroup/<int:pk>/delete/", VolumeGroupDeleteView.as_view(), name="volumegroup_delete"),
+    path(
+        "volumegroup/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="volumegroup_changelog",
+        kwargs={"model": VolumeGroup},
+    ),
+    #
+    # Physical Volume urls
+    #
+    path("physicalvolume/", PhysicalVolumeListView.as_view(), name="physicalvolume_list"),
+    path("physicalvolume/add/", PhysicalVolumeEditView.as_view(), name="physicalvolume_add"),
+    # path("physicalvolume/import/", PhysicalVolumeBulkImportView.as_view(), name="physicalvolume_import"),
+    # path("physicalvolume/edit/", PhysicalVolumeBulkEditView.as_view(), name="physicalvolume_bulk_edit"),
+    # path("physicalvolume/delete/", PhysicalVolumeBulkDeleteView.as_view(), name="physicalvolume_bulk_delete"),
+    path("physicalvolume/<int:pk>/", PhysicalVolumeView.as_view(), name="physicalvolume"),
+    path("physicalvolume/<int:pk>/edit/", PhysicalVolumeEditView.as_view(), name="physicalvolume_edit"),
+    path("physicalvolume/<int:pk>/delete/", PhysicalVolumeDeleteView.as_view(), name="physicalvolume_delete"),
+    path(
+        "physicalvolume/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="physicalvolume_changelog",
+        kwargs={"model": PhysicalVolume},
+    ),
+    #
     # Simple Configuration
     #
     path('lvm-add/', LVMAddSimpleView.as_view(), name='lvm_add'),
@@ -142,7 +200,6 @@ urlpatterns = [
     # Template Configuration
     #
     path('template-lvm-add/', LVMAddTemplateView.as_view(), name='template_lvm_add'),
-    path('template-volume-add/', AddTemplateVolumeView.as_view(), name="template_volume_add"),
     path('template-drive-add/', AddTemplateDriveView.as_view(), name='template_drive_add'),
     path('template-partition-add', AddTemplatePartitionView.as_view(), name='template_partition_add')
 ]
